@@ -1,6 +1,6 @@
 #' @rdname p_value_betwithin
 #' @export
-ci_betwithin <- function(model, ci = .95) {
+ci_betwithin <- function(model, ci = .95, ...) {
   df_bet <- dof_ml1(model)
   out <- lapply(ci, function(i) {
     .ci_dof(
@@ -9,7 +9,8 @@ ci_betwithin <- function(model, ci = .95) {
       effects = "fixed",
       component = "all",
       dof = df_bet,
-      method = "betwithin"
+      method = "betwithin",
+      ...
     )
   })
   out <- do.call(rbind, out)
