@@ -51,7 +51,7 @@ format_p_adjust <- function(method) {
         correction <- 1
         by_vars <- model@misc$by.vars
         if (!is.null(by_vars) && by_vars %in% colnames(params)) {
-          correction <- .n_unique(params[[by_vars]])
+          correction <- insight::n_unique(params[[by_vars]])
         }
         correction
       },
@@ -75,7 +75,13 @@ format_p_adjust <- function(method) {
       } else if (tolower(p_adjust) == "tukey") {
         # tukey adjustment
         if ("df" %in% colnames(params) && length(stat_column) > 0) {
-          params$p <- stats::ptukey(sqrt(2) * abs(params[[stat_column]]), nrow(params) / rank_adjust, params$df, lower.tail = FALSE)
+          params$p <- suppressWarnings(stats::ptukey(sqrt(2) * abs(params[[stat_column]]), nrow(params) / rank_adjust, params$df, lower.tail = FALSE))
+          # for specific contrasts, ptukey might fail, and the tukey-adjustement
+          # could just be simple p-value calculation
+          if (all(is.na(params$p))) {
+            params$p <- 2 * stats::pt(abs(params[[stat_column]]), df = params$df, lower.tail = FALSE)
+            verbose <- FALSE
+          }
         }
       } else if (tolower(p_adjust) == "scheffe" && !is.null(model)) {
         # scheffe adjustment
@@ -105,7 +111,7 @@ format_p_adjust <- function(method) {
 
       if (isTRUE(all.equal(old_p_vals, params$p)) && !identical(p_adjust, "none")) {
         if (verbose) {
-          warning(paste0("Something went wrong. Could not apply ", p_adjust, "-adjustment."), call. = FALSE)
+          warning(insight::format_message(paste0("Could not apply ", p_adjust, "-adjustment to p-values. Either something went wrong, or the non-adjusted p-values were already very large.")), call. = FALSE)
         }
       }
     } else if (verbose) {
