@@ -2,15 +2,17 @@
 model_parameters.bayesQR <- function(model,
                                      centrality = "median",
                                      dispersion = FALSE,
-                                     ci = .89,
-                                     ci_method = "hdi",
+                                     ci = .95,
+                                     ci_method = "eti",
                                      test = c("pd", "rope"),
                                      rope_range = "default",
-                                     rope_ci = 1.0,
+                                     rope_ci = 0.95,
                                      bf_prior = NULL,
                                      diagnostic = c("ESS", "Rhat"),
                                      priors = TRUE,
-                                     parameters = NULL,
+                                     keep = NULL,
+                                     drop = NULL,
+                                     parameters = keep,
                                      verbose = TRUE,
                                      ...) {
 
@@ -28,7 +30,8 @@ model_parameters.bayesQR <- function(model,
     bf_prior = bf_prior,
     diagnostic = diagnostic,
     priors = priors,
-    filter_parameters = parameters,
+    keep_parameters = keep,
+    drop_parameters = drop,
     verbose = verbose,
     ...
   )
