@@ -1,18 +1,31 @@
 #' Parameters from Cluster Models (k-means, ...)
 #'
-#' Format cluster models obtained for example by \code{\link{kmeans}}.
+#' Format cluster models obtained for example by [kmeans()].
 #'
 #' @param model Cluster model.
 #' @inheritParams model_parameters.default
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @examples
-#' library(parameters)
-#'
+#' \dontrun{
+#' #
+#' # K-means -------------------------------
 #' model <- kmeans(iris[1:4], centers = 3)
-#' model_parameters(model)
+#' rez <- model_parameters(model)
+#' rez
+#'
+#' # Get clusters
+#' predict(rez)
+#'
+#' # Clusters centers in long form
+#' attributes(rez)$means
+#'
+#' # Between and Total Sum of Squares
+#' attributes(rez)$Sum_Squares_Total
+#' attributes(rez)$Sum_Squares_Between
+#' }
 #' @export
-model_parameters.kmeans <- function(model, verbose = TRUE, ...) {
+model_parameters.kmeans <- function(model, ...) {
   params <- cbind(
     data.frame(
       Cluster = row.names(model$centers),
@@ -23,11 +36,16 @@ model_parameters.kmeans <- function(model, verbose = TRUE, ...) {
   )
 
   # Long means
-  means <- .long_loadings(params, loadings_columns = 4:ncol(params))
-  means <- means[c("Cluster", "Loading", "Component")]
-  names(means) <- c("Cluster", "Mean", "Variable")
+  means <- datawizard::reshape_longer(params,
+    cols = 4:ncol(params),
+    values_to = "Mean",
+    names_to = "Variable"
+  )
 
+  # Attributes
   attr(params, "variance") <- model$betweenss / model$totss
+  attr(params, "Sum_Squares_Between") <- model$betweenss
+  attr(params, "Sum_Squares_Total") <- model$totss
   attr(params, "means") <- means
   attr(params, "model") <- model
   attr(params, "iterations") <- model$iter
@@ -39,9 +57,54 @@ model_parameters.kmeans <- function(model, verbose = TRUE, ...) {
 }
 
 
+
+
+
+# factoextra::hkmeans -----------------------------------------------------
+
+
+
+#' @rdname model_parameters.kmeans
+#' @inheritParams cluster_centers
+#'
+#' @examples
+#' \dontrun{
+#' #
+#' # Hierarchical K-means (factoextra::hkclust) ----------------------
+#' if (require("factoextra", quietly = TRUE)) {
+#'   data <- iris[1:4]
+#'   model <- factoextra::hkmeans(data, k = 3)
+#'
+#'   rez <- model_parameters(model)
+#'   rez
+#'
+#'   # Get clusters
+#'   predict(rez)
+#'
+#'   # Clusters centers in long form
+#'   attributes(rez)$means
+#'
+#'   # Between and Total Sum of Squares
+#'   attributes(rez)$Sum_Squares_Total
+#'   attributes(rez)$Sum_Squares_Between
+#' }
+#' }
+#' @export
+model_parameters.hkmeans <- model_parameters.kmeans
+
+
+
+# Methods -------------------------------------------------------------------
+
+
+
+
 #' @export
 print.parameters_clusters <- function(x, digits = 2, ...) {
-  insight::print_color("# K-means Cluster Means", "blue")
+  title <- "# Clustering Solution"
+  if ("title" %in% attributes(x)) title <- attributes(x)$title
+
+  insight::print_color(title, "blue")
 
   cat("\n\n")
   insight::print_colour(.text_components_variance(x), "yellow")
@@ -53,13 +116,19 @@ print.parameters_clusters <- function(x, digits = 2, ...) {
 }
 
 
-#' @export
-summary.parameters_clusters <- function(object, ...) {
-  object[1:3]
-}
 
 
+
+
+# Predict -----------------------------------------------------------------
+
+
+#' Predict method for parameters_clusters objects
+#'
 #' @export
+#' @param names character vector or list
+#' @param newdata data.frame
+#' @inheritParams stats::predict
 predict.parameters_clusters <- function(object, newdata = NULL, names = NULL, ...) {
   if (is.null(newdata)) {
     out <- attributes(object)$scores
@@ -90,6 +159,7 @@ predict.parameters_clusters <- function(object, newdata = NULL, names = NULL, ..
 
 
 #' @export
+#' @inheritParams stats::predict
 predict.kmeans <- function(object, newdata = NULL, ...) {
   if (is.null(newdata)) {
     return(object$cluster)
