@@ -13,7 +13,6 @@ model_parameters.merModList <- function(model,
     merge_by = "Parameter",
     standardize = NULL,
     exponentiate = exponentiate,
-    robust = FALSE,
     p_adjust = p_adjust,
     ...
   )
@@ -25,7 +24,7 @@ model_parameters.merModList <- function(model,
 
 #' @export
 ci.merModList <- function(x, ci = .95, ...) {
-  ci_wald(model = x, ci = ci, dof = NULL, robust = FALSE, component = "conditional")
+  .ci_generic(model = x, ci = ci, dof = NULL, component = "conditional", ...)
 }
 
 
@@ -36,7 +35,7 @@ standard_error.merModList <- function(model, ...) {
     Parameter = s$fe$term,
     SE = s$fe$std.error
   )
-  .remove_backticks_from_parameter_names(out)
+  insight::text_remove_backticks(out, verbose = FALSE)
 }
 
 
@@ -47,13 +46,6 @@ degrees_of_freedom.merModList <- function(model, ...) {
 }
 
 
-#' @export
-p_value.merModList <- function(model, ...) {
-  dof <- degrees_of_freedom(model)
-  p_value_wald(model, dof, ...)
-}
-
-
 #' @export
 format_parameters.merModList <- function(model, brackets = c("[", "]"), ...) {
   .format_parameter_default(model[[1]], brackets = brackets)
