@@ -90,6 +90,6 @@ simulate_model.mhurdle <- function(model, iterations = 1000, component = c("all"
   out <- .simulate_model(model, iterations, component = component, effects = "fixed")
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- .safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
   out
 }
