@@ -27,7 +27,6 @@ model_parameters.wbm <- function(model,
     standardize = NULL,
     exponentiate = exponentiate,
     effects = effects,
-    robust = FALSE,
     p_adjust = p_adjust,
     group_level = group_level,
     ci_method = NULL,
@@ -115,7 +114,6 @@ p_value.wbgee <- p_value.wbm
                                             standardize,
                                             exponentiate,
                                             effects,
-                                            robust,
                                             p_adjust,
                                             group_level,
                                             ci_method,
@@ -133,7 +131,6 @@ p_value.wbgee <- p_value.wbm
       standardize = standardize,
       exponentiate = exponentiate,
       effects = "fixed",
-      robust = FALSE,
       p_adjust = p_adjust,
       ci_method = ci_method,
       include_sigma = include_sigma,
