@@ -81,17 +81,30 @@ print_md.parameters_model <- function(x,
   )
 }
 
+#' @export
+print_md.parameters_stan <- print_md.parameters_model
+
 #' @export
 print_md.parameters_brms_meta <- print_md.parameters_model
 
 #' @export
 print_md.parameters_simulate <- print_md.parameters_model
 
+
+
+
+
+# compare parameters -------------------------
+
+
 #' @export
 print_md.compare_parameters <- function(x,
                                         digits = 2,
                                         ci_digits = 2,
                                         p_digits = 3,
+                                        caption = NULL,
+                                        subtitle = NULL,
+                                        footer = NULL,
                                         style = NULL,
                                         ...) {
   # check if user supplied digits attributes
@@ -122,14 +135,20 @@ print_md.compare_parameters <- function(x,
     format = "markdown"
   )
 
-  insight::export_table(formatted_table, format = "markdown", footer = NULL)
+  insight::export_table(
+    formatted_table,
+    format = "markdown",
+    caption = caption,
+    subtitle = subtitle,
+    footer = footer
+  )
 }
 
 
 
 
 
-# Stan / SEM print ----------------------------
+# SEM print ----------------------------
 
 #' @export
 print_md.parameters_sem <- function(x,
@@ -154,25 +173,6 @@ print_md.parameters_sem <- function(x,
   insight::export_table(formatted_table, format = "markdown", align = "firstleft", ...)
 }
 
-#' @export
-print_md.parameters_stan <- function(x, split_components = TRUE, select = NULL, digits = 2, ci_digits = 2, p_digits = 3, ...) {
-  # check if user supplied digits attributes
-  # check if user supplied digits attributes
-  if (missing(digits)) {
-    digits <- .additional_arguments(x, "digits", digits)
-  }
-  if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
-  }
-  if (missing(p_digits)) {
-    p_digits <- .additional_arguments(x, "p_digits", p_digits)
-  }
-
-  formatted_table <- format(x = x, split_components = split_components, select = select, format = "markdown", digits = digits, ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = c("(", ")"), ...)
-  insight::export_table(formatted_table, format = "markdown")
-}
-
-
 
 
 
@@ -230,13 +230,12 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ci_brackets = c("(", ")"
 
   formatted_table <- insight::format_table(x, pretty_names = TRUE, digits = digits, ci_width = NULL, ci_brackets = ci_brackets, zap_small = zap_small, ...)
 
-  colnames(formatted_table)[which(colnames(formatted_table) == "ROPE_Equivalence")] <- "H0"
-  formatted_table$ROPE_low <- NULL
-  formatted_table$ROPE_high <- NULL
+  colnames(formatted_table)[which(colnames(formatted_table) == "Equivalence (ROPE)")] <- "H0"
+  formatted_table$ROPE <- NULL
 
-  col_order <- c("Parameter", "H0", "% in ROPE", colnames(formatted_table)[grepl(" CI$", colnames(formatted_table))])
-  col_order <- c(col_order, setdiff(colnames(formatted_table), col_order))
-  formatted_table <- formatted_table[col_order]
+  # col_order <- c("Parameter", "H0", "% in ROPE", colnames(formatted_table)[grepl(" CI$", colnames(formatted_table))])
+  # col_order <- c(col_order, setdiff(colnames(formatted_table), col_order))
+  # formatted_table <- formatted_table[col_order]
 
   # replace brackets by parenthesis
   if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
