@@ -1,4 +1,4 @@
-if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requiet("lme4") && requiet("parameters")) {
+if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requiet("lme4") && requiet("parameters") && requiet("effectsize") && utils::packageVersion("effectsize") > "0.5.0") {
   unloadNamespace("afex")
   unloadNamespace("lmerTest")
   data(iris)
@@ -8,7 +8,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
   # aov ----------------------------------
 
   test_that("model_parameters.aov", {
-    skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+    skip_if_not_installed("effectsize", minimum_version = "0.5.1")
     model <- aov(Sepal.Width ~ Species, data = iris)
     mp <- suppressMessages(model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9))
     es <- suppressMessages(effectsize::omega_squared(model, partial = TRUE, ci = .9))
@@ -43,7 +43,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
 
   data(mtcars)
   test_that("model_parameters.anova", {
-    skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+    skip_if_not_installed("effectsize", minimum_version = "0.5.1")
     model <- anova(lm(Sepal.Length ~ Species * Cat1 * Cat2, data = iris))
     mp <- model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9)
     es <- effectsize::omega_squared(model, partial = TRUE, ci = .9)
@@ -60,11 +60,13 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
 
   data(mtcars)
   test_that("model_parameters.anova", {
-    skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+    skip_if_not_installed("effectsize", minimum_version = "0.5.1")
     model <- aov(wt ~ cyl + Error(gear), data = mtcars)
-    mp <- model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9)
-    es <- effectsize::omega_squared(model, partial = TRUE, ci = .9)
-    expect_equal(na.omit(mp$Omega2_CI_low), es$CI_low, tolerance = 1e-3, ignore_attr = TRUE)
+    suppressWarnings({
+      mp <- model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9)
+      es <- effectsize::omega_squared(model, partial = TRUE, ci = .9, verbose = FALSE)
+    })
+    expect_equal(na.omit(mp$Omega2_CI_low), es$CI_low[2], tolerance = 1e-3, ignore_attr = TRUE)
     expect_equal(na.omit(mp$Omega2_CI_high), es$CI_high, tolerance = 1e-3, ignore_attr = TRUE)
 
     expect_equal(colnames(mp), c(
@@ -88,7 +90,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
         contrasts = list(fcategory = contr.sum, partner.status = contr.sum)
       ))
     test_that("model_parameters.car-anova", {
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+      skip_if_not_installed("effectsize", minimum_version = "0.5.1")
       mp <- model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9)
       es <- effectsize::omega_squared(model, partial = TRUE, ci = .9)
       expect_equal(na.omit(mp$Omega2_CI_low), es$CI_low, tolerance = 1e-3, ignore_attr = TRUE)
@@ -113,11 +115,11 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
   model <- aov(fit)
 
   test_that("model_parameters.maov", {
-    skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+    skip_if_not_installed("effectsize", minimum_version = "0.5.1")
     mp <- suppressMessages(model_parameters(model, omega_squared = "partial", eta_squared = "partial", epsilon_squared = TRUE, ci = .9))
     es <- suppressMessages(effectsize::omega_squared(model, partial = TRUE, ci = .9))
     expect_equal(na.omit(mp$Omega2_CI_low), es$CI_low, tolerance = 1e-3, ignore_attr = TRUE)
-    expect_equal(mp$Omega2_CI_low, c(0.74092, NA, 0.55331, NA, 0.58067, NA), tolerance = 1e-3, ignore_attr = TRUE)
+    expect_equal(mp$Omega2_CI_low, c(0.58067, NA, 0.74092, NA, 0.55331, NA), tolerance = 1e-3, ignore_attr = TRUE)
     expect_equal(na.omit(mp$Omega2_CI_high), es$CI_high, tolerance = 1e-3, ignore_attr = TRUE)
     expect_equal(na.omit(mp$Omega2_CI_high), rep(1, 3), tolerance = 1e-3, ignore_attr = TRUE)
 
@@ -137,7 +139,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
 
     test_that("works with aov", {
       skip_on_cran()
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+      skip_if_not_installed("effectsize", minimum_version = "0.5.1")
 
       set.seed(123)
       npk.aov <- aov(yield ~ block + N * P, npk)
@@ -252,7 +254,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
 
     test_that("works with manova", {
       skip_on_cran()
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+      skip_if_not_installed("effectsize", minimum_version = "0.5.1")
 
       set.seed(123)
       # fake a 2nd response variable
@@ -299,71 +301,11 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
       )
     })
 
-    # maov ------------------------------------------------
-
-    test_that("works with maov", {
-      skip_on_cran()
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
-
-      set.seed(123)
-      fit <- lm(cbind(mpg, disp, hp) ~ factor(cyl), data = mtcars)
-      m <- aov(fit)
-
-      set.seed(123)
-      df_maov <-
-        as.data.frame(model_parameters(m,
-          ci = 0.95,
-          eta_squared = "partial",
-          omega_squared = "raw",
-          epsilon_squared = "raw"
-        ))
-
-      expect_equal(
-        df_maov,
-        structure(
-          list(
-            Response = c("mpg", "mpg", "disp", "disp", "hp", "hp"),
-            Parameter = c(
-              "factor(cyl)",
-              "Residuals",
-              "factor(cyl)",
-              "Residuals",
-              "factor(cyl)",
-              "Residuals"
-            ),
-            Sum_Squares = c(824.78, 301.26, 398890.96, 77293.83, 104030.54, 41696.33),
-            df = c(2, 29, 2, 29, 2, 29),
-            Mean_Square = c(412.39, 10.39, 199445.48, 2665.3, 52015.27, 1437.8),
-            F = c(39.7, NA, 74.83, NA, 36.18, NA),
-            p = c(0, NA, 0, NA, 0, NA),
-            Omega2 = c(0.82, NA, 0.69, NA, 0.71, NA),
-            Omega2_CI_low = c(0.68, NA, 0.47, NA, 0.5, NA),
-            Omega2_CI_high = c(1, NA, 1, NA, 1, NA),
-            Eta2 = c(0.84, NA, 0.71, NA, 0.73, NA),
-            Eta2_CI_low = c(0.71, NA, 0.51, NA, 0.54, NA),
-            Eta2_CI_high = c(1, NA, 1, NA, 1, NA),
-            Epsilon2 = c(0.83, NA, 0.69, NA, 0.71, NA),
-            Epsilon2_CI_low = c(0.69, NA, 0.48, NA, 0.51, NA),
-            Epsilon2_CI_high = c(1, NA, 1, NA, 1, NA)
-          ),
-          row.names = c(NA, 6L),
-          class = "data.frame",
-          ci = 0.95,
-          model_class = c("maov", "aov", "mlm", "lm"),
-          digits = 2,
-          ci_digits = 2,
-          p_digits = 3
-        ),
-        tolerance = 0.1,
-        ignore_attr = TRUE
-      )
-    })
-
     # Gam ------------------------------------------------
 
     test_that("works with Gam", {
       skip_on_cran()
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+      skip_if_not_installed("effectsize", minimum_version = "0.5.1")
 
       # setup
       set.seed(123)
@@ -414,7 +356,7 @@ if (requiet("insight") && requiet("effectsize") && requiet("testthat") && requie
 
     test_that("works with anova", {
       skip_on_cran()
-      skip_if_not_installed("effectsize", minimum_version = "0.5.0")
+      skip_if_not_installed("effectsize", minimum_version = "0.5.1")
 
       set.seed(123)
       mod <-
