@@ -40,7 +40,7 @@ if (requiet("testthat") && requiet("parameters") && requiet("effectsize") && uti
     expect_equal(colnames(mp), c("Chi2", "df", "p", "Method"))
   })
 
-  mp2 <- model_parameters(stats::chisq.test(table(mtcars$am, mtcars$cyl)))
+  mp2 <- suppressWarnings(model_parameters(stats::chisq.test(table(mtcars$am, mtcars$cyl))))
 
   test_that("model_parameters-chisq-test two way table", {
     expect_equal(mp2$Chi2, 8.740733, tolerance = 1e-3)
